@@ -5,7 +5,7 @@
 
 import logging
 import sys
-logging.basicConfig(format="%(asctime)s %(levelname)s %(message)s",
+logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
                     level=logging.DEBUG,
                     stream=sys.stdout)
 import time
