@@ -420,6 +420,7 @@ def create_pfile(output_filename, feature_count, data):
     input_filename = "tmp.pfile"
     f = open(input_filename, "w")
 
+    logging.debug(data)
     for symbolnr, instance in enumerate(data):
         feature_string, label = instance
         assert len(feature_string) == feature_count, \
@@ -428,6 +429,7 @@ def create_pfile(output_filename, feature_count, data):
         feature_string = " ".join(map(str, feature_string))
         line = "%i 0 %s %i" % (symbolnr, feature_string, label)
         print(line, file=f)
+        logging.debug(line)
 
     command = "pfile_create -i %s -f %i -l 1 -o %s" % \
               (input_filename, feature_count, output_filename)
